==> ejc-middlemeasurement-impl-3.0.0-20221021.114700-173-sources.jar: com/ejianc/business/change/vo/ChangeVisaclaimaccountdetailVO.java <==
package com.ejianc.business.change.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;


/**
 * 总包签证索赔台账变更子表
 * 
 * @author generator
 * 
 */
public class ChangeVisaclaimaccountdetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private java.lang.Long changeMid; // 变更主表id
    private java.lang.Long mid; // 主表id
    private Long originalId; // 原始单据id
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private String sort; // 序号
    private String changeContent; // 变更内容
    private Long departmentId; // 存档部门
    private String departmentName; // 存档部门名称
    private String changeCode; // 变更编号
    private String bargainingBasist; // 合同议价依据
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date contractSubmissionDate; // 我方报送日期(合同约定)
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date actualSubmissionDate; // 我方报送日期(实际报送)
    private BigDecimal exSubmittedAmount; // 我方报送金额(除税)(元)
    private BigDecimal inSubmittedAmount; // 我方报送金额(含税)(元)
    private BigDecimal exConfirmedAmount; // 对方确认金额(除税)(元)
    private BigDecimal inConfirmedAmount; // 对方确认金额(含税)(元)
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date dueDate; // 应付日期(当期或结算)
    private BigDecimal exPayableAmount; // 应付金额(除税)(元)
    private BigDecimal inPayableAmount; // 应付金额(含税)(元)
    private BigDecimal exPaidinAmount; // 实付金额(除税)(元)
    private BigDecimal inPaidinAmount; // 实付金额(含税)(元)
    private Integer changeDate; // 涉及工期变更天数
    private Integer deferredDays; // 发包人认可工期顺延天数
    private String personLiable; // 责任人
    private String remarks; // 备注
    private Long changeId; // 变更单据id
    private String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    private java.lang.String tid;
    private java.lang.String tpid;
    private List<ChangeVisaclaimaccountdetailVO> children = new ArrayList<>();

    public Long getMid() {
        return mid;
    }

    public void setMid(Long mid) {
        this.mid = mid;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }

    public List<ChangeVisaclaimaccountdetailVO> getChildren() {
        return children;
    }

    public void setChildren(List<ChangeVisaclaimaccountdetailVO> children) {
        this.children = children;
    }

    public Long getChangeMid() {
        return changeMid;
    }

    public void setChangeMid(Long changeMid) {
        this.changeMid = changeMid;
    }

    public Long getOriginalId() {
        return originalId;
    }

    public void setOriginalId(Long originalId) {
        this.originalId = originalId;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getSort() {
        return sort;
    }

    public void setSort(String sort) {
        this.sort = sort;
    }
    public String getChangeContent() {
        return changeContent;
    }

    public void setChangeContent(String changeContent) {
        this.changeContent = changeContent;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public String getChangeCode() {
        return changeCode;
    }

    public void setChangeCode(String changeCode) {
        this.changeCode = changeCode;
    }
    public String getBargainingBasist() {
        return bargainingBasist;
    }

    public void setBargainingBasist(String bargainingBasist) {
        this.bargainingBasist = bargainingBasist;
    }
    public Date getContractSubmissionDate() {
        return contractSubmissionDate;
    }

    public void setContractSubmissionDate(Date contractSubmissionDate) {
        this.contractSubmissionDate = contractSubmissionDate;
    }
    public Date getActualSubmissionDate() {
        return actualSubmissionDate;
    }

    public void setActualSubmissionDate(Date actualSubmissionDate) {
        this.actualSubmissionDate = actualSubmissionDate;
    }
    public BigDecimal getExSubmittedAmount() {
        return exSubmittedAmount;
    }

    public void setExSubmittedAmount(BigDecimal exSubmittedAmount) {
        this.exSubmittedAmount = exSubmittedAmount;
    }
    public BigDecimal getInSubmittedAmount() {
        return inSubmittedAmount;
    }

    public void setInSubmittedAmount(BigDecimal inSubmittedAmount) {
        this.inSubmittedAmount = inSubmittedAmount;
    }
    public BigDecimal getExConfirmedAmount() {
        return exConfirmedAmount;
    }

    public void setExConfirmedAmount(BigDecimal exConfirmedAmount) {
        this.exConfirmedAmount = exConfirmedAmount;
    }
    public BigDecimal getInConfirmedAmount() {
        return inConfirmedAmount;
    }

    public void setInConfirmedAmount(BigDecimal inConfirmedAmount) {
        this.inConfirmedAmount = inConfirmedAmount;
    }
    public Date getDueDate() {
        return dueDate;
    }

    public void setDueDate(Date dueDate) {
        this.dueDate = dueDate;
    }
    public BigDecimal getExPayableAmount() {
        return exPayableAmount;
    }

    public void setExPayableAmount(BigDecimal exPayableAmount) {
        this.exPayableAmount = exPayableAmount;
    }
    public BigDecimal getInPayableAmount() {
        return inPayableAmount;
    }

    public void setInPayableAmount(BigDecimal inPayableAmount) {
        this.inPayableAmount = inPayableAmount;
    }
    public BigDecimal getExPaidinAmount() {
        return exPaidinAmount;
    }

    public void setExPaidinAmount(BigDecimal exPaidinAmount) {
        this.exPaidinAmount = exPaidinAmount;
    }
    public BigDecimal getInPaidinAmount() {
        return inPaidinAmount;
    }

    public void setInPaidinAmount(BigDecimal inPaidinAmount) {
        this.inPaidinAmount = inPaidinAmount;
    }
    public Integer getChangeDate() {
        return changeDate;
    }

    public void setChangeDate(Integer changeDate) {
        this.changeDate = changeDate;
    }
    public Integer getDeferredDays() {
        return deferredDays;
    }

    public void setDeferredDays(Integer deferredDays) {
        this.deferredDays = deferredDays;
    }
    public String getPersonLiable() {
        return personLiable;
    }

    public void setPersonLiable(String personLiable) {
        this.personLiable = personLiable;
    }
    public String getRemarks() {
        return remarks;
    }

    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public String getChangeState() {
        return changeState;
    }

    public void setChangeState(String changeState) {
        this.changeState = changeState;
    }
    
}

==> ejc-middlemeasurement-impl-3.0.0-20221219.062630-293-sources.jar: com/ejianc/business/change/vo/ChangeVisaclaimaccountdetailVO.java <==
package com.ejianc.business.change.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;


/**
 * 总包签证索赔台账变更子表
 * 
 * @author generator
 * 
 */
public class ChangeVisaclaimaccountdetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private java.lang.Long changeMid; // 变更主表id
    private java.lang.Long mid; // 主表id
    private Long originalId; // 原始单据id
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private String sort; // 序号
    private String changeContent; // 变更内容
    private Long departmentId; // 存档部门
    private String departmentName; // 存档部门名称
    private String changeCode; // 变更编号
    private String bargainingBasist; // 合同议价依据
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date contractSubmissionDate; // 我方报送日期(合同约定)
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date actualSubmissionDate; // 我方报送日期(实际报送)
    private BigDecimal exSubmittedAmount; // 我方报送金额(除税)(元)
    private BigDecimal inSubmittedAmount; // 我方报送金额(含税)(元)
    private BigDecimal exConfirmedAmount; // 对方确认金额(除税)(元)
    private BigDecimal inConfirmedAmount; // 对方确认金额(含税)(元)
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date dueDate; // 应付日期(当期或结算)
    private BigDecimal exPayableAmount; // 应付金额(除税)(元)
    private BigDecimal inPayableAmount; // 应付金额(含税)(元)
    private BigDecimal exPaidinAmount; // 实付金额(除税)(元)
    private BigDecimal inPaidinAmount; // 实付金额(含税)(元)
    private Integer changeDate; // 涉及工期变更天数
    private Integer deferredDays; // 发包人认可工期顺延天数
    private String personLiable; // 责任人
    private String remarks; // 备注
    private Long changeId; // 变更单据id
    private String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    private java.lang.String tid;
    private java.lang.String tpid;
    private List<ChangeVisaclaimaccountdetailVO> children = new ArrayList<>();
    private java.lang.String contractSubmissionDateShow;//我方报送日期(合同约定)文本显示
    private java.lang.String actualSubmissionDateShow;//我方报送日期(实际报送)文本显示
    private java.lang.String dueDateShow;//应付日期(当期或结算)文本显示


    private java.lang.String errorMsg;

    public String getContractSubmissionDateShow() {
        return contractSubmissionDateShow;
    }

    public void setContractSubmissionDateShow(String contractSubmissionDateShow) {
        this.contractSubmissionDateShow = contractSubmissionDateShow;
    }

    public String getActualSubmissionDateShow() {
        return actualSubmissionDateShow;
    }

    public void setActualSubmissionDateShow(String actualSubmissionDateShow) {
        this.actualSubmissionDateShow = actualSubmissionDateShow;
    }

    public String getDueDateShow() {
        return dueDateShow;
    }

    public void setDueDateShow(String dueDateShow) {
        this.dueDateShow = dueDateShow;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    public Long getMid() {
        return mid;
    }

    public void setMid(Long mid) {
        this.mid = mid;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }

    public List<ChangeVisaclaimaccountdetailVO> getChildren() {
        return children;
    }

    public void setChildren(List<ChangeVisaclaimaccountdetailVO> children) {
        this.children = children;
    }

    public Long getChangeMid() {
        return changeMid;
    }

    public void setChangeMid(Long changeMid) {
        this.changeMid = changeMid;
    }

    public Long getOriginalId() {
        return originalId;
    }

    public void setOriginalId(Long originalId) {
        this.originalId = originalId;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getSort() {
        return sort;
    }

    public void setSort(String sort) {
        this.sort = sort;
    }
    public String getChangeContent() {
        return changeContent;
    }

    public void setChangeContent(String changeContent) {
        this.changeContent = changeContent;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public String getChangeCode() {
        return changeCode;
    }

    public void setChangeCode(String changeCode) {
        this.changeCode = changeCode;
    }
    public String getBargainingBasist() {
        return bargainingBasist;
    }

    public void setBargainingBasist(String bargainingBasist) {
        this.bargainingBasist = bargainingBasist;
    }
    public Date getContractSubmissionDate() {
        return contractSubmissionDate;
    }

    public void setContractSubmissionDate(Date contractSubmissionDate) {
        this.contractSubmissionDate = contractSubmissionDate;
    }
    public Date getActualSubmissionDate() {
        return actualSubmissionDate;
    }

    public void setActualSubmissionDate(Date actualSubmissionDate) {
        this.actualSubmissionDate = actualSubmissionDate;
    }
    public BigDecimal getExSubmittedAmount() {
        return exSubmittedAmount;
    }

    public void setExSubmittedAmount(BigDecimal exSubmittedAmount) {
        this.exSubmittedAmount = exSubmittedAmount;
    }
    public BigDecimal getInSubmittedAmount() {
        return inSubmittedAmount;
    }

    public void setInSubmittedAmount(BigDecimal inSubmittedAmount) {
        this.inSubmittedAmount = inSubmittedAmount;
    }
    public BigDecimal getExConfirmedAmount() {
        return exConfirmedAmount;
    }

    public void setExConfirmedAmount(BigDecimal exConfirmedAmount) {
        this.exConfirmedAmount = exConfirmedAmount;
    }
    public BigDecimal getInConfirmedAmount() {
        return inConfirmedAmount;
    }

    public void setInConfirmedAmount(BigDecimal inConfirmedAmount) {
        this.inConfirmedAmount = inConfirmedAmount;
    }
    public Date getDueDate() {
        return dueDate;
    }

    public void setDueDate(Date dueDate) {
        this.dueDate = dueDate;
    }
    public BigDecimal getExPayableAmount() {
        return exPayableAmount;
    }

    public void setExPayableAmount(BigDecimal exPayableAmount) {
        this.exPayableAmount = exPayableAmount;
    }
    public BigDecimal getInPayableAmount() {
        return inPayableAmount;
    }

    public void setInPayableAmount(BigDecimal inPayableAmount) {
        this.inPayableAmount = inPayableAmount;
    }
    public BigDecimal getExPaidinAmount() {
        return exPaidinAmount;
    }

    public void setExPaidinAmount(BigDecimal exPaidinAmount) {
        this.exPaidinAmount = exPaidinAmount;
    }
    public BigDecimal getInPaidinAmount() {
        return inPaidinAmount;
    }

    public void setInPaidinAmount(BigDecimal inPaidinAmount) {
        this.inPaidinAmount = inPaidinAmount;
    }
    public Integer getChangeDate() {
        return changeDate;
    }

    public void setChangeDate(Integer changeDate) {
        this.changeDate = changeDate;
    }
    public Integer getDeferredDays() {
        return deferredDays;
    }

    public void setDeferredDays(Integer deferredDays) {
        this.deferredDays = deferredDays;
    }
    public String getPersonLiable() {
        return personLiable;
    }

    public void setPersonLiable(String personLiable) {
        this.personLiable = personLiable;
    }
    public String getRemarks() {
        return remarks;
    }

    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public String getChangeState() {
        return changeState;
    }

    public void setChangeState(String changeState) {
        this.changeState = changeState;
    }
    
}
